@@ -51,6 +51,8 @@ function (obj, append=FALSE, file=FALSE, filename="temp.html", clipboard.size=40
   } 
   if (Sys.info()["sysname"] == "Darwin") conn <- pipe("pbcopy", "w", encoding="Latin1")
   if (Sys.info()["sysname"] == "Linux") conn <- pipe("xclip -i", "w", encoding="Latin1")
+  # Convert tibble to data.frame
+  if (inherits(obj, "tbl_df")) obj <- data.frame(obj)
   R2HTML::HTML(obj, file = conn, append = append, ...)
   close(conn)
 }
